"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generate = exports.HttpClient = void 0;
const v2_1 = require("./openApi/v2");
const v3_1 = require("./openApi/v3");
const getOpenApiSpec_1 = require("./utils/getOpenApiSpec");
const getOpenApiVersion_1 = require("./utils/getOpenApiVersion");
const isString_1 = require("./utils/isString");
const postProcessClient_1 = require("./utils/postProcessClient");
const readHandlebarsTemplates_1 = require("./utils/readHandlebarsTemplates");
const writeClient_1 = require("./utils/writeClient");
var HttpClient;
(function (HttpClient) {
    HttpClient["FETCH"] = "fetch";
    HttpClient["XHR"] = "xhr";
})(HttpClient = exports.HttpClient || (exports.HttpClient = {}));
function generate({ input, output, httpClient = HttpClient.FETCH, useOptions = false, useUnionTypes = false, exportCore = true, exportServices = true, exportModels = true, exportSchemas = false, write = true, }) {
    try {
        const openApi = isString_1.isString(input) ? getOpenApiSpec_1.getOpenApiSpec(input) : input;
        const openApiVersion = getOpenApiVersion_1.getOpenApiVersion(openApi);
        const templates = readHandlebarsTemplates_1.readHandlebarsTemplates();
        switch (openApiVersion) {
            case getOpenApiVersion_1.OpenApiVersion.V2: {
                const client = v2_1.parse(openApi);
                const clientFinal = postProcessClient_1.postProcessClient(client, useUnionTypes);
                if (write) {
                    writeClient_1.writeClient(clientFinal, templates, output, httpClient, useOptions, exportCore, exportServices, exportModels, exportSchemas);
                }
                break;
            }
            case getOpenApiVersion_1.OpenApiVersion.V3: {
                const client = v3_1.parse(openApi);
                const clientFinal = postProcessClient_1.postProcessClient(client, useUnionTypes);
                if (write) {
                    writeClient_1.writeClient(clientFinal, templates, output, httpClient, useOptions, exportCore, exportServices, exportModels, exportSchemas);
                }
                break;
            }
        }
    }
    catch (e) {
        console.error(e);
        process.exit(1);
    }
}
exports.generate = generate;
