"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getOpenApiSpec = void 0;
const fs = require("fs");
const yaml = require("js-yaml");
const path = require("path");
function read(filePath) {
    if (fs.existsSync(filePath)) {
        try {
            return fs.readFileSync(filePath, 'utf8').toString();
        }
        catch (e) {
            throw new Error(`Could not read OpenApi spec: "${filePath}"`);
        }
    }
    throw new Error(`Could not find OpenApi spec: "${filePath}"`);
}
function getOpenApiSpec(input) {
    const file = path.resolve(process.cwd(), input);
    const extname = path.extname(file).toLowerCase();
    const content = read(file);
    switch (extname) {
        case '.yml':
        case '.yaml':
            try {
                return yaml.safeLoad(content);
            }
            catch (e) {
                throw new Error(`Could not parse OpenApi YAML: "${file}"`);
            }
        default:
            try {
                return JSON.parse(content);
            }
            catch (e) {
                throw new Error(`Could not parse OpenApi JSON: "${file}"`);
            }
    }
}
exports.getOpenApiSpec = getOpenApiSpec;
