"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.readHandlebarsTemplates = void 0;
const Handlebars = require("handlebars/runtime");
const path = require("path");
const readHandlebarsTemplate_1 = require("./readHandlebarsTemplate");
const registerHandlebarHelpers_1 = require("./registerHandlebarHelpers");
function resolveTemplate(filePath) {
    return path.resolve(__dirname, `../../src/templates/${filePath}`);
}
function readHandlebarsTemplates() {
    registerHandlebarHelpers_1.registerHandlebarHelpers();
    const templates = {
        index: readHandlebarsTemplate_1.readHandlebarsTemplate(resolveTemplate('index.js')),
        model: readHandlebarsTemplate_1.readHandlebarsTemplate(resolveTemplate('model.js')),
        schema: readHandlebarsTemplate_1.readHandlebarsTemplate(resolveTemplate('schema.js')),
        service: readHandlebarsTemplate_1.readHandlebarsTemplate(resolveTemplate('service.js')),
        settings: readHandlebarsTemplate_1.readHandlebarsTemplate(resolveTemplate('core/OpenAPI.js')),
    };
    const partials = [
        'exportEnum.js',
        'exportInterface.js',
        'exportType.js',
        'extends.js',
        'isNullable.js',
        'isReadOnly.js',
        'isRequired.js',
        'parameters.js',
        'result.js',
        'schema.js',
        'schemaArray.js',
        'schemaDictionary.js',
        'schemaEnum.js',
        'schemaGeneric.js',
        'schemaInterface.js',
        'type.js',
        'typeArray.js',
        'typeDictionary.js',
        'typeEnum.js',
        'typeGeneric.js',
        'typeInterface.js',
        'typeReference.js',
    ];
    partials.forEach(partial => {
        const templatePath = resolveTemplate(`partials/${partial}`);
        const templateName = path.basename(partial, '.js');
        const template = readHandlebarsTemplate_1.readHandlebarsTemplate(templatePath);
        Handlebars.registerPartial(templateName, template);
    });
    return templates;
}
exports.readHandlebarsTemplates = readHandlebarsTemplates;
