"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeClient = void 0;
const fs = require("fs");
const mkdirp = require("mkdirp");
const path = require("path");
const rimraf = require("rimraf");
const writeClientIndex_1 = require("./writeClientIndex");
const writeClientModels_1 = require("./writeClientModels");
const writeClientSchemas_1 = require("./writeClientSchemas");
const writeClientServices_1 = require("./writeClientServices");
const writeClientSettings_1 = require("./writeClientSettings");
function copySupportFile(filePath, outputPath) {
    fs.copyFileSync(path.resolve(__dirname, `../../src/templates/${filePath}`), path.resolve(outputPath, filePath));
}
function writeClient(client, templates, output, httpClient, useOptions, exportCore, exportServices, exportModels, exportSchemas) {
    const outputPath = path.resolve(process.cwd(), output);
    const outputPathCore = path.resolve(outputPath, 'core');
    const outputPathModels = path.resolve(outputPath, 'models');
    const outputPathSchemas = path.resolve(outputPath, 'schemas');
    const outputPathServices = path.resolve(outputPath, 'services');
    rimraf.sync(outputPath);
    mkdirp.sync(outputPath);
    if (exportCore) {
        mkdirp.sync(outputPathCore);
        copySupportFile('core/ApiError.ts', outputPath);
        copySupportFile('core/getFormData.ts', outputPath);
        copySupportFile('core/getQueryString.ts', outputPath);
        copySupportFile('core/isSuccess.ts', outputPath);
        copySupportFile('core/request.ts', outputPath);
        copySupportFile('core/RequestOptions.ts', outputPath);
        copySupportFile('core/requestUsingFetch.ts', outputPath);
        copySupportFile('core/requestUsingXHR.ts', outputPath);
        copySupportFile('core/Result.ts', outputPath);
    }
    if (exportServices) {
        mkdirp.sync(outputPathServices);
        writeClientSettings_1.writeClientSettings(client, templates, outputPathCore, httpClient);
        writeClientServices_1.writeClientServices(client.services, templates, outputPathServices, useOptions);
    }
    if (exportSchemas) {
        mkdirp.sync(outputPathSchemas);
        writeClientSchemas_1.writeClientSchemas(client.models, templates, outputPathSchemas);
    }
    if (exportModels) {
        mkdirp.sync(outputPathModels);
        copySupportFile('models/Dictionary.ts', outputPath);
        writeClientModels_1.writeClientModels(client.models, templates, outputPathModels);
    }
    writeClientIndex_1.writeClientIndex(client, templates, outputPath, exportCore, exportModels, exportServices, exportSchemas);
}
exports.writeClient = writeClient;
